@@ -30,7 +30,6 @@ from novaclient import base
 from novaclient import crypto
 from novaclient import exceptions
 from novaclient.i18n import _
-from novaclient.v2 import security_groups
 
 
 REBOOT_SOFT, REBOOT_HARD = 'SOFT', 'HARD'
@@ -632,6 +631,11 @@ class NetworkInterface(base.Resource):
         return '<NetworkInterface: %s>' % self.id
 
 
+class SecurityGroup(base.Resource):
+    def __str__(self):
+        return str(self.id)
+
+
 class ServerManager(base.BootingManagerWithFind):
     resource_class = Server
 
@@ -1631,9 +1635,9 @@ class ServerManager(base.BootingManagerWithFind):
 
     def set_meta(self, server, metadata):
         """
-        Set a servers metadata
+        Set a server's metadata
         :param server: The :class:`Server` to add metadata to
-        :param metadata: A dict of metadata to add to the server
+        :param metadata: A dict of metadata to be added to the server
         """
         body = {'metadata': metadata}
         return self._create("/servers/%s/metadata" % base.getid(server),
@@ -1780,7 +1784,7 @@ class ServerManager(base.BootingManagerWithFind):
         """
         return self._list('/servers/%s/os-security-groups' %
                           base.getid(server), 'security_groups',
-                          security_groups.SecurityGroup)
+                          SecurityGroup)
 
     @api_versions.wraps("2.0", "2.13")
     def evacuate(self, server, host=None, on_shared_storage=True,
